# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.volumes_api import VolumesApi  # noqa: E501
from Vpsa.rest import ApiException


class TestVolumesApi(unittest.TestCase):
    """VolumesApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.volumes_api.VolumesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_directories_to_quota_project(self):
        """Test case for add_directories_to_quota_project

        """
        pass

    def test_add_quota_limit(self):
        """Test case for add_quota_limit

        """
        pass

    def test_add_secondary_export_name(self):
        """Test case for add_secondary_export_name

        """
        pass

    def test_attach_snapshot_policy(self):
        """Test case for attach_snapshot_policy

        """
        pass

    def test_cancel_volume_migration(self):
        """Test case for cancel_volume_migration

        """
        pass

    def test_create_clone(self):
        """Test case for create_clone

        """
        pass

    def test_create_quota_project(self):
        """Test case for create_quota_project

        """
        pass

    def test_create_volume(self):
        """Test case for create_volume

        """
        pass

    def test_create_volume_mirror(self):
        """Test case for create_volume_mirror

        """
        pass

    def test_create_volume_snapshot(self):
        """Test case for create_volume_snapshot

        """
        pass

    def test_create_volume_tag(self):
        """Test case for create_volume_tag

        """
        pass

    def test_delete_quota_project(self):
        """Test case for delete_quota_project

        """
        pass

    def test_delete_secondary_export_name(self):
        """Test case for delete_secondary_export_name

        """
        pass

    def test_delete_volume(self):
        """Test case for delete_volume

        """
        pass

    def test_delete_volume_file_history(self):
        """Test case for delete_volume_file_history

        """
        pass

    def test_delete_volume_from_recycle_bin(self):
        """Test case for delete_volume_from_recycle_bin

        """
        pass

    def test_delete_volume_snapshot(self):
        """Test case for delete_volume_snapshot

        """
        pass

    def test_delete_volume_tag(self):
        """Test case for delete_volume_tag

        """
        pass

    def test_detach_servers_from_volume(self):
        """Test case for detach_servers_from_volume

        """
        pass

    def test_detach_snapshot_policy(self):
        """Test case for detach_snapshot_policy

        """
        pass

    def test_dump_quotas_file(self):
        """Test case for dump_quotas_file

        """
        pass

    def test_dump_quotas_state(self):
        """Test case for dump_quotas_state

        """
        pass

    def test_expand_volume(self):
        """Test case for expand_volume

        """
        pass

    def test_fetch_volume_quotas(self):
        """Test case for fetch_volume_quotas

        """
        pass

    def test_get_all_snapshots(self):
        """Test case for get_all_snapshots

        """
        pass

    def test_get_free_volumes(self):
        """Test case for get_free_volumes

        """
        pass

    def test_get_quota_projects(self):
        """Test case for get_quota_projects

        """
        pass

    def test_get_servers_attached_to_volume(self):
        """Test case for get_servers_attached_to_volume

        """
        pass

    def test_get_snapshot(self):
        """Test case for get_snapshot

        """
        pass

    def test_get_vol_tags(self):
        """Test case for get_vol_tags

        """
        pass

    def test_get_vols_file_access_auditing_log_time(self):
        """Test case for get_vols_file_access_auditing_log_time

        """
        pass

    def test_get_vols_file_access_auditing_log_time_zip(self):
        """Test case for get_vols_file_access_auditing_log_time_zip

        """
        pass

    def test_get_volume(self):
        """Test case for get_volume

        """
        pass

    def test_get_volume_attached_snapshot_policies(self):
        """Test case for get_volume_attached_snapshot_policies

        """
        pass

    def test_get_volume_file_history(self):
        """Test case for get_volume_file_history

        """
        pass

    def test_get_volume_migration(self):
        """Test case for get_volume_migration

        """
        pass

    def test_get_volume_performance(self):
        """Test case for get_volume_performance

        """
        pass

    def test_get_volume_quota(self):
        """Test case for get_volume_quota

        """
        pass

    def test_import_volume_quotas(self):
        """Test case for import_volume_quotas

        """
        pass

    def test_migrate_volume(self):
        """Test case for migrate_volume

        """
        pass

    def test_pause_volume_migration(self):
        """Test case for pause_volume_migration

        """
        pass

    def test_pause_volume_snapshot_policy(self):
        """Test case for pause_volume_snapshot_policy

        """
        pass

    def test_remove_directories_from_quota_project(self):
        """Test case for remove_directories_from_quota_project

        """
        pass

    def test_rename_volume(self):
        """Test case for rename_volume

        """
        pass

    def test_resume_volume_migration(self):
        """Test case for resume_volume_migration

        """
        pass

    def test_set_volume_attach_permissions(self):
        """Test case for set_volume_attach_permissions

        """
        pass

    def test_set_volume_export_name(self):
        """Test case for set_volume_export_name

        """
        pass

    def test_show_all_volumes(self):
        """Test case for show_all_volumes

        """
        pass

    def test_update_protection(self):
        """Test case for update_protection

        """
        pass

    def test_update_vol_perf_threshold(self):
        """Test case for update_vol_perf_threshold

        """
        pass

    def test_update_volume_nas_options(self):
        """Test case for update_volume_nas_options

        """
        pass

    def test_update_volume_quotas_state(self):
        """Test case for update_volume_quotas_state

        """
        pass

    def test_update_volume_tag(self):
        """Test case for update_volume_tag

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2001Clouds(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'resources': 'InlineResponse2001Resources',
        'inventory': 'list[InlineResponse2001Inventory]',
        'networking': 'InlineResponse2001Networking'
    }

    attribute_map = {
        'name': 'name',
        'resources': 'resources',
        'inventory': 'inventory',
        'networking': 'networking'
    }

    def __init__(self, name=None, resources=None, inventory=None, networking=None, _configuration=None):  # noqa: E501
        """InlineResponse2001Clouds - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._resources = None
        self._inventory = None
        self._networking = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if resources is not None:
            self.resources = resources
        if inventory is not None:
            self.inventory = inventory
        if networking is not None:
            self.networking = networking

    @property
    def name(self):
        """Gets the name of this InlineResponse2001Clouds.  # noqa: E501


        :return: The name of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse2001Clouds.


        :param name: The name of this InlineResponse2001Clouds.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resources(self):
        """Gets the resources of this InlineResponse2001Clouds.  # noqa: E501


        :return: The resources of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: InlineResponse2001Resources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this InlineResponse2001Clouds.


        :param resources: The resources of this InlineResponse2001Clouds.  # noqa: E501
        :type: InlineResponse2001Resources
        """

        self._resources = resources

    @property
    def inventory(self):
        """Gets the inventory of this InlineResponse2001Clouds.  # noqa: E501


        :return: The inventory of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: list[InlineResponse2001Inventory]
        """
        return self._inventory

    @inventory.setter
    def inventory(self, inventory):
        """Sets the inventory of this InlineResponse2001Clouds.


        :param inventory: The inventory of this InlineResponse2001Clouds.  # noqa: E501
        :type: list[InlineResponse2001Inventory]
        """

        self._inventory = inventory

    @property
    def networking(self):
        """Gets the networking of this InlineResponse2001Clouds.  # noqa: E501


        :return: The networking of this InlineResponse2001Clouds.  # noqa: E501
        :rtype: InlineResponse2001Networking
        """
        return self._networking

    @networking.setter
    def networking(self, networking):
        """Sets the networking of this InlineResponse2001Clouds.


        :param networking: The networking of this InlineResponse2001Clouds.  # noqa: E501
        :type: InlineResponse2001Networking
        """

        self._networking = networking

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001Clouds, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001Clouds):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001Clouds):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20080MessageSteps(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'name': 'str',
        'state': 'str',
        'time': 'str',
        'phase': 'int',
        'progress': 'str',
        'data': 'InlineResponse20080MessageData',
        'id': 'int',
        'action_id': 'int'
    }

    attribute_map = {
        'comment': 'comment',
        'name': 'name',
        'state': 'state',
        'time': 'time',
        'phase': 'phase',
        'progress': 'progress',
        'data': 'data',
        'id': 'id',
        'action_id': 'action-id'
    }

    def __init__(self, comment=None, name=None, state=None, time=None, phase=None, progress=None, data=None, id=None, action_id=None, _configuration=None):  # noqa: E501
        """InlineResponse20080MessageSteps - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._comment = None
        self._name = None
        self._state = None
        self._time = None
        self._phase = None
        self._progress = None
        self._data = None
        self._id = None
        self._action_id = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if name is not None:
            self.name = name
        if state is not None:
            self.state = state
        if time is not None:
            self.time = time
        if phase is not None:
            self.phase = phase
        if progress is not None:
            self.progress = progress
        if data is not None:
            self.data = data
        if id is not None:
            self.id = id
        if action_id is not None:
            self.action_id = action_id

    @property
    def comment(self):
        """Gets the comment of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The comment of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse20080MessageSteps.


        :param comment: The comment of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def name(self):
        """Gets the name of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The name of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20080MessageSteps.


        :param name: The name of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """Gets the state of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The state of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InlineResponse20080MessageSteps.


        :param state: The state of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def time(self):
        """Gets the time of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The time of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this InlineResponse20080MessageSteps.


        :param time: The time of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def phase(self):
        """Gets the phase of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The phase of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: int
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        """Sets the phase of this InlineResponse20080MessageSteps.


        :param phase: The phase of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: int
        """

        self._phase = phase

    @property
    def progress(self):
        """Gets the progress of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The progress of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: str
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this InlineResponse20080MessageSteps.


        :param progress: The progress of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: str
        """

        self._progress = progress

    @property
    def data(self):
        """Gets the data of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The data of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: InlineResponse20080MessageData
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this InlineResponse20080MessageSteps.


        :param data: The data of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: InlineResponse20080MessageData
        """

        self._data = data

    @property
    def id(self):
        """Gets the id of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The id of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20080MessageSteps.


        :param id: The id of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def action_id(self):
        """Gets the action_id of this InlineResponse20080MessageSteps.  # noqa: E501


        :return: The action_id of this InlineResponse20080MessageSteps.  # noqa: E501
        :rtype: int
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this InlineResponse20080MessageSteps.


        :param action_id: The action_id of this InlineResponse20080MessageSteps.  # noqa: E501
        :type: int
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20080MessageSteps, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20080MessageSteps):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20080MessageSteps):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20018ResponseVnis(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'ip': 'str',
        'ipv6': 'str',
        'gateway': 'str',
        'ipv6_gateway': 'str',
        'netmask': 'str',
        'ipv6_netmask': 'str',
        'vlan_id': 'int',
        'interface': 'str',
        'net_uuid': 'str'
    }

    attribute_map = {
        'id': 'id',
        'ip': 'ip',
        'ipv6': 'ipv6',
        'gateway': 'gateway',
        'ipv6_gateway': 'ipv6_gateway',
        'netmask': 'netmask',
        'ipv6_netmask': 'ipv6_netmask',
        'vlan_id': 'vlan_id',
        'interface': 'interface',
        'net_uuid': 'net_uuid'
    }

    def __init__(self, id=None, ip=None, ipv6=None, gateway=None, ipv6_gateway=None, netmask=None, ipv6_netmask=None, vlan_id=None, interface=None, net_uuid=None, _configuration=None):  # noqa: E501
        """InlineResponse20018ResponseVnis - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._ip = None
        self._ipv6 = None
        self._gateway = None
        self._ipv6_gateway = None
        self._netmask = None
        self._ipv6_netmask = None
        self._vlan_id = None
        self._interface = None
        self._net_uuid = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if ip is not None:
            self.ip = ip
        if ipv6 is not None:
            self.ipv6 = ipv6
        if gateway is not None:
            self.gateway = gateway
        if ipv6_gateway is not None:
            self.ipv6_gateway = ipv6_gateway
        if netmask is not None:
            self.netmask = netmask
        if ipv6_netmask is not None:
            self.ipv6_netmask = ipv6_netmask
        if vlan_id is not None:
            self.vlan_id = vlan_id
        if interface is not None:
            self.interface = interface
        if net_uuid is not None:
            self.net_uuid = net_uuid

    @property
    def id(self):
        """Gets the id of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The id of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20018ResponseVnis.


        :param id: The id of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def ip(self):
        """Gets the ip of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The ip of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this InlineResponse20018ResponseVnis.


        :param ip: The ip of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def ipv6(self):
        """Gets the ipv6 of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The ipv6 of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._ipv6

    @ipv6.setter
    def ipv6(self, ipv6):
        """Sets the ipv6 of this InlineResponse20018ResponseVnis.


        :param ipv6: The ipv6 of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._ipv6 = ipv6

    @property
    def gateway(self):
        """Gets the gateway of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The gateway of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this InlineResponse20018ResponseVnis.


        :param gateway: The gateway of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def ipv6_gateway(self):
        """Gets the ipv6_gateway of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The ipv6_gateway of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_gateway

    @ipv6_gateway.setter
    def ipv6_gateway(self, ipv6_gateway):
        """Sets the ipv6_gateway of this InlineResponse20018ResponseVnis.


        :param ipv6_gateway: The ipv6_gateway of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._ipv6_gateway = ipv6_gateway

    @property
    def netmask(self):
        """Gets the netmask of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The netmask of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """Sets the netmask of this InlineResponse20018ResponseVnis.


        :param netmask: The netmask of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._netmask = netmask

    @property
    def ipv6_netmask(self):
        """Gets the ipv6_netmask of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The ipv6_netmask of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_netmask

    @ipv6_netmask.setter
    def ipv6_netmask(self, ipv6_netmask):
        """Sets the ipv6_netmask of this InlineResponse20018ResponseVnis.


        :param ipv6_netmask: The ipv6_netmask of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._ipv6_netmask = ipv6_netmask

    @property
    def vlan_id(self):
        """Gets the vlan_id of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The vlan_id of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: int
        """
        return self._vlan_id

    @vlan_id.setter
    def vlan_id(self, vlan_id):
        """Sets the vlan_id of this InlineResponse20018ResponseVnis.


        :param vlan_id: The vlan_id of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: int
        """

        self._vlan_id = vlan_id

    @property
    def interface(self):
        """Gets the interface of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The interface of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._interface

    @interface.setter
    def interface(self, interface):
        """Sets the interface of this InlineResponse20018ResponseVnis.


        :param interface: The interface of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._interface = interface

    @property
    def net_uuid(self):
        """Gets the net_uuid of this InlineResponse20018ResponseVnis.  # noqa: E501


        :return: The net_uuid of this InlineResponse20018ResponseVnis.  # noqa: E501
        :rtype: str
        """
        return self._net_uuid

    @net_uuid.setter
    def net_uuid(self, net_uuid):
        """Sets the net_uuid of this InlineResponse20018ResponseVnis.


        :param net_uuid: The net_uuid of this InlineResponse20018ResponseVnis.  # noqa: E501
        :type: str
        """

        self._net_uuid = net_uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20018ResponseVnis, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20018ResponseVnis):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20018ResponseVnis):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class Volume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'size': 'int',
        'vpsa_id': 'int',
        'vpsa_name': 'str',
        'vpsa_internal_name': 'str',
        'url': 'str',
        'flc': 'bool',
        'drive': 'VolumeDrive'
    }

    attribute_map = {
        'id': 'id',
        'size': 'size',
        'vpsa_id': 'vpsa_id',
        'vpsa_name': 'vpsa_name',
        'vpsa_internal_name': 'vpsa_internal_name',
        'url': 'url',
        'flc': 'flc',
        'drive': 'drive'
    }

    def __init__(self, id=None, size=None, vpsa_id=None, vpsa_name=None, vpsa_internal_name=None, url=None, flc=None, drive=None, _configuration=None):  # noqa: E501
        """Volume - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._size = None
        self._vpsa_id = None
        self._vpsa_name = None
        self._vpsa_internal_name = None
        self._url = None
        self._flc = None
        self._drive = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if size is not None:
            self.size = size
        if vpsa_id is not None:
            self.vpsa_id = vpsa_id
        if vpsa_name is not None:
            self.vpsa_name = vpsa_name
        if vpsa_internal_name is not None:
            self.vpsa_internal_name = vpsa_internal_name
        if url is not None:
            self.url = url
        if flc is not None:
            self.flc = flc
        if drive is not None:
            self.drive = drive

    @property
    def id(self):
        """Gets the id of this Volume.  # noqa: E501


        :return: The id of this Volume.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Volume.


        :param id: The id of this Volume.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def size(self):
        """Gets the size of this Volume.  # noqa: E501


        :return: The size of this Volume.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Volume.


        :param size: The size of this Volume.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def vpsa_id(self):
        """Gets the vpsa_id of this Volume.  # noqa: E501


        :return: The vpsa_id of this Volume.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_id

    @vpsa_id.setter
    def vpsa_id(self, vpsa_id):
        """Sets the vpsa_id of this Volume.


        :param vpsa_id: The vpsa_id of this Volume.  # noqa: E501
        :type: int
        """

        self._vpsa_id = vpsa_id

    @property
    def vpsa_name(self):
        """Gets the vpsa_name of this Volume.  # noqa: E501


        :return: The vpsa_name of this Volume.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_name

    @vpsa_name.setter
    def vpsa_name(self, vpsa_name):
        """Sets the vpsa_name of this Volume.


        :param vpsa_name: The vpsa_name of this Volume.  # noqa: E501
        :type: str
        """

        self._vpsa_name = vpsa_name

    @property
    def vpsa_internal_name(self):
        """Gets the vpsa_internal_name of this Volume.  # noqa: E501


        :return: The vpsa_internal_name of this Volume.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_internal_name

    @vpsa_internal_name.setter
    def vpsa_internal_name(self, vpsa_internal_name):
        """Sets the vpsa_internal_name of this Volume.


        :param vpsa_internal_name: The vpsa_internal_name of this Volume.  # noqa: E501
        :type: str
        """

        self._vpsa_internal_name = vpsa_internal_name

    @property
    def url(self):
        """Gets the url of this Volume.  # noqa: E501


        :return: The url of this Volume.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Volume.


        :param url: The url of this Volume.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def flc(self):
        """Gets the flc of this Volume.  # noqa: E501


        :return: The flc of this Volume.  # noqa: E501
        :rtype: bool
        """
        return self._flc

    @flc.setter
    def flc(self, flc):
        """Sets the flc of this Volume.


        :param flc: The flc of this Volume.  # noqa: E501
        :type: bool
        """

        self._flc = flc

    @property
    def drive(self):
        """Gets the drive of this Volume.  # noqa: E501


        :return: The drive of this Volume.  # noqa: E501
        :rtype: VolumeDrive
        """
        return self._drive

    @drive.setter
    def drive(self, drive):
        """Sets the drive of this Volume.


        :param drive: The drive of this Volume.  # noqa: E501
        :type: VolumeDrive
        """

        self._drive = drive

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Volume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Volume):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Volume):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20010CommentsComment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'content': 'str',
        'severity_id': 'str',
        'severity_name': 'str',
        'created_by': 'str',
        'created_at': 'str'
    }

    attribute_map = {
        'content': 'content',
        'severity_id': 'severity_id',
        'severity_name': 'severity_name',
        'created_by': 'created_by',
        'created_at': 'created_at'
    }

    def __init__(self, content=None, severity_id=None, severity_name=None, created_by=None, created_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20010CommentsComment - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._content = None
        self._severity_id = None
        self._severity_name = None
        self._created_by = None
        self._created_at = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if severity_id is not None:
            self.severity_id = severity_id
        if severity_name is not None:
            self.severity_name = severity_name
        if created_by is not None:
            self.created_by = created_by
        if created_at is not None:
            self.created_at = created_at

    @property
    def content(self):
        """Gets the content of this InlineResponse20010CommentsComment.  # noqa: E501


        :return: The content of this InlineResponse20010CommentsComment.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this InlineResponse20010CommentsComment.


        :param content: The content of this InlineResponse20010CommentsComment.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def severity_id(self):
        """Gets the severity_id of this InlineResponse20010CommentsComment.  # noqa: E501


        :return: The severity_id of this InlineResponse20010CommentsComment.  # noqa: E501
        :rtype: str
        """
        return self._severity_id

    @severity_id.setter
    def severity_id(self, severity_id):
        """Sets the severity_id of this InlineResponse20010CommentsComment.


        :param severity_id: The severity_id of this InlineResponse20010CommentsComment.  # noqa: E501
        :type: str
        """

        self._severity_id = severity_id

    @property
    def severity_name(self):
        """Gets the severity_name of this InlineResponse20010CommentsComment.  # noqa: E501


        :return: The severity_name of this InlineResponse20010CommentsComment.  # noqa: E501
        :rtype: str
        """
        return self._severity_name

    @severity_name.setter
    def severity_name(self, severity_name):
        """Sets the severity_name of this InlineResponse20010CommentsComment.


        :param severity_name: The severity_name of this InlineResponse20010CommentsComment.  # noqa: E501
        :type: str
        """

        self._severity_name = severity_name

    @property
    def created_by(self):
        """Gets the created_by of this InlineResponse20010CommentsComment.  # noqa: E501


        :return: The created_by of this InlineResponse20010CommentsComment.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this InlineResponse20010CommentsComment.


        :param created_by: The created_by of this InlineResponse20010CommentsComment.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20010CommentsComment.  # noqa: E501


        :return: The created_at of this InlineResponse20010CommentsComment.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20010CommentsComment.


        :param created_at: The created_at of this InlineResponse20010CommentsComment.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20010CommentsComment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20010CommentsComment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20010CommentsComment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class UpdateFlcPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'file_selection_criteria': 'str',
        'lc_action': 'str',
        'enabled': 'str',
        'dry_run': 'str',
        'use_recycle_bin': 'str',
        'whitelist_paths': 'str',
        'blacklist_paths': 'str',
        'dest_obs_name': 'str'
    }

    attribute_map = {
        'display_name': 'display_name',
        'file_selection_criteria': 'file_selection_criteria',
        'lc_action': 'lc_action',
        'enabled': 'enabled',
        'dry_run': 'dry_run',
        'use_recycle_bin': 'use_recycle_bin',
        'whitelist_paths': 'whitelist_paths',
        'blacklist_paths': 'blacklist_paths',
        'dest_obs_name': 'dest_obs_name'
    }

    def __init__(self, display_name=None, file_selection_criteria=None, lc_action=None, enabled=None, dry_run=None, use_recycle_bin=None, whitelist_paths=None, blacklist_paths=None, dest_obs_name=None, _configuration=None):  # noqa: E501
        """UpdateFlcPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._display_name = None
        self._file_selection_criteria = None
        self._lc_action = None
        self._enabled = None
        self._dry_run = None
        self._use_recycle_bin = None
        self._whitelist_paths = None
        self._blacklist_paths = None
        self._dest_obs_name = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if file_selection_criteria is not None:
            self.file_selection_criteria = file_selection_criteria
        if lc_action is not None:
            self.lc_action = lc_action
        if enabled is not None:
            self.enabled = enabled
        if dry_run is not None:
            self.dry_run = dry_run
        if use_recycle_bin is not None:
            self.use_recycle_bin = use_recycle_bin
        if whitelist_paths is not None:
            self.whitelist_paths = whitelist_paths
        if blacklist_paths is not None:
            self.blacklist_paths = blacklist_paths
        if dest_obs_name is not None:
            self.dest_obs_name = dest_obs_name

    @property
    def display_name(self):
        """Gets the display_name of this UpdateFlcPolicy.  # noqa: E501

        Policy name.  # noqa: E501

        :return: The display_name of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UpdateFlcPolicy.

        Policy name.  # noqa: E501

        :param display_name: The display_name of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def file_selection_criteria(self):
        """Gets the file_selection_criteria of this UpdateFlcPolicy.  # noqa: E501

        The criteria by which the policy files will be selected. Should be in a MongoDB $match aggregation format.  # noqa: E501

        :return: The file_selection_criteria of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._file_selection_criteria

    @file_selection_criteria.setter
    def file_selection_criteria(self, file_selection_criteria):
        """Sets the file_selection_criteria of this UpdateFlcPolicy.

        The criteria by which the policy files will be selected. Should be in a MongoDB $match aggregation format.  # noqa: E501

        :param file_selection_criteria: The file_selection_criteria of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """

        self._file_selection_criteria = file_selection_criteria

    @property
    def lc_action(self):
        """Gets the lc_action of this UpdateFlcPolicy.  # noqa: E501

        The action that the policy performs on the selected files.  # noqa: E501

        :return: The lc_action of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._lc_action

    @lc_action.setter
    def lc_action(self, lc_action):
        """Sets the lc_action of this UpdateFlcPolicy.

        The action that the policy performs on the selected files.  # noqa: E501

        :param lc_action: The lc_action of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """
        allowed_values = ["archive", "expire"]  # noqa: E501
        if (self._configuration.client_side_validation and
                lc_action not in allowed_values):
            raise ValueError(
                "Invalid value for `lc_action` ({0}), must be one of {1}"  # noqa: E501
                .format(lc_action, allowed_values)
            )

        self._lc_action = lc_action

    @property
    def enabled(self):
        """Gets the enabled of this UpdateFlcPolicy.  # noqa: E501

        Controls enablement of the policy after it is created.  # noqa: E501

        :return: The enabled of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this UpdateFlcPolicy.

        Controls enablement of the policy after it is created.  # noqa: E501

        :param enabled: The enabled of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                enabled not in allowed_values):
            raise ValueError(
                "Invalid value for `enabled` ({0}), must be one of {1}"  # noqa: E501
                .format(enabled, allowed_values)
            )

        self._enabled = enabled

    @property
    def dry_run(self):
        """Gets the dry_run of this UpdateFlcPolicy.  # noqa: E501

        When the policy is in dry run mode, it'll only print its actions to the log instead of actually performing them.  # noqa: E501

        :return: The dry_run of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._dry_run

    @dry_run.setter
    def dry_run(self, dry_run):
        """Sets the dry_run of this UpdateFlcPolicy.

        When the policy is in dry run mode, it'll only print its actions to the log instead of actually performing them.  # noqa: E501

        :param dry_run: The dry_run of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                dry_run not in allowed_values):
            raise ValueError(
                "Invalid value for `dry_run` ({0}), must be one of {1}"  # noqa: E501
                .format(dry_run, allowed_values)
            )

        self._dry_run = dry_run

    @property
    def use_recycle_bin(self):
        """Gets the use_recycle_bin of this UpdateFlcPolicy.  # noqa: E501

        When using recycle bin, files that are handled by the policy are also copied to the recycle bin.  # noqa: E501

        :return: The use_recycle_bin of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._use_recycle_bin

    @use_recycle_bin.setter
    def use_recycle_bin(self, use_recycle_bin):
        """Sets the use_recycle_bin of this UpdateFlcPolicy.

        When using recycle bin, files that are handled by the policy are also copied to the recycle bin.  # noqa: E501

        :param use_recycle_bin: The use_recycle_bin of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                use_recycle_bin not in allowed_values):
            raise ValueError(
                "Invalid value for `use_recycle_bin` ({0}), must be one of {1}"  # noqa: E501
                .format(use_recycle_bin, allowed_values)
            )

        self._use_recycle_bin = use_recycle_bin

    @property
    def whitelist_paths(self):
        """Gets the whitelist_paths of this UpdateFlcPolicy.  # noqa: E501

        Comma delimited list of paths that the policy should only run on them.  # noqa: E501

        :return: The whitelist_paths of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._whitelist_paths

    @whitelist_paths.setter
    def whitelist_paths(self, whitelist_paths):
        """Sets the whitelist_paths of this UpdateFlcPolicy.

        Comma delimited list of paths that the policy should only run on them.  # noqa: E501

        :param whitelist_paths: The whitelist_paths of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """

        self._whitelist_paths = whitelist_paths

    @property
    def blacklist_paths(self):
        """Gets the blacklist_paths of this UpdateFlcPolicy.  # noqa: E501

        Comma delimited list of paths that the policy should not run on.  # noqa: E501

        :return: The blacklist_paths of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._blacklist_paths

    @blacklist_paths.setter
    def blacklist_paths(self, blacklist_paths):
        """Sets the blacklist_paths of this UpdateFlcPolicy.

        Comma delimited list of paths that the policy should not run on.  # noqa: E501

        :param blacklist_paths: The blacklist_paths of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """

        self._blacklist_paths = blacklist_paths

    @property
    def dest_obs_name(self):
        """Gets the dest_obs_name of this UpdateFlcPolicy.  # noqa: E501

        Destination object storage to archive files to.  # noqa: E501

        :return: The dest_obs_name of this UpdateFlcPolicy.  # noqa: E501
        :rtype: str
        """
        return self._dest_obs_name

    @dest_obs_name.setter
    def dest_obs_name(self, dest_obs_name):
        """Sets the dest_obs_name of this UpdateFlcPolicy.

        Destination object storage to archive files to.  # noqa: E501

        :param dest_obs_name: The dest_obs_name of this UpdateFlcPolicy.  # noqa: E501
        :type: str
        """

        self._dest_obs_name = dest_obs_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateFlcPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateFlcPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateFlcPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse2003PublicIps(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'cloud_id': 'int',
        'vpsa_id': 'int',
        'public_address': 'str',
        'vlan': 'int',
        'label': 'str',
        'netmask': 'str',
        'address': 'str',
        'internal_id': 'int',
        'network_label': 'str',
        'gateway': 'str',
        'created_at': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'cloud_id': 'cloud_id',
        'vpsa_id': 'vpsa_id',
        'public_address': 'public_address',
        'vlan': 'vlan',
        'label': 'label',
        'netmask': 'netmask',
        'address': 'address',
        'internal_id': 'internal_id',
        'network_label': 'network_label',
        'gateway': 'gateway',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, cloud_id=None, vpsa_id=None, public_address=None, vlan=None, label=None, netmask=None, address=None, internal_id=None, network_label=None, gateway=None, created_at=None, updated_at=None, _configuration=None):  # noqa: E501
        """InlineResponse2003PublicIps - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._cloud_id = None
        self._vpsa_id = None
        self._public_address = None
        self._vlan = None
        self._label = None
        self._netmask = None
        self._address = None
        self._internal_id = None
        self._network_label = None
        self._gateway = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if cloud_id is not None:
            self.cloud_id = cloud_id
        if vpsa_id is not None:
            self.vpsa_id = vpsa_id
        if public_address is not None:
            self.public_address = public_address
        if vlan is not None:
            self.vlan = vlan
        if label is not None:
            self.label = label
        if netmask is not None:
            self.netmask = netmask
        if address is not None:
            self.address = address
        if internal_id is not None:
            self.internal_id = internal_id
        if network_label is not None:
            self.network_label = network_label
        if gateway is not None:
            self.gateway = gateway
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The id of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse2003PublicIps.


        :param id: The id of this InlineResponse2003PublicIps.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def cloud_id(self):
        """Gets the cloud_id of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The cloud_id of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: int
        """
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, cloud_id):
        """Sets the cloud_id of this InlineResponse2003PublicIps.


        :param cloud_id: The cloud_id of this InlineResponse2003PublicIps.  # noqa: E501
        :type: int
        """

        self._cloud_id = cloud_id

    @property
    def vpsa_id(self):
        """Gets the vpsa_id of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The vpsa_id of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_id

    @vpsa_id.setter
    def vpsa_id(self, vpsa_id):
        """Sets the vpsa_id of this InlineResponse2003PublicIps.


        :param vpsa_id: The vpsa_id of this InlineResponse2003PublicIps.  # noqa: E501
        :type: int
        """

        self._vpsa_id = vpsa_id

    @property
    def public_address(self):
        """Gets the public_address of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The public_address of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._public_address

    @public_address.setter
    def public_address(self, public_address):
        """Sets the public_address of this InlineResponse2003PublicIps.


        :param public_address: The public_address of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._public_address = public_address

    @property
    def vlan(self):
        """Gets the vlan of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The vlan of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: int
        """
        return self._vlan

    @vlan.setter
    def vlan(self, vlan):
        """Sets the vlan of this InlineResponse2003PublicIps.


        :param vlan: The vlan of this InlineResponse2003PublicIps.  # noqa: E501
        :type: int
        """

        self._vlan = vlan

    @property
    def label(self):
        """Gets the label of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The label of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this InlineResponse2003PublicIps.


        :param label: The label of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def netmask(self):
        """Gets the netmask of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The netmask of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """Sets the netmask of this InlineResponse2003PublicIps.


        :param netmask: The netmask of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._netmask = netmask

    @property
    def address(self):
        """Gets the address of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The address of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this InlineResponse2003PublicIps.


        :param address: The address of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def internal_id(self):
        """Gets the internal_id of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The internal_id of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: int
        """
        return self._internal_id

    @internal_id.setter
    def internal_id(self, internal_id):
        """Sets the internal_id of this InlineResponse2003PublicIps.


        :param internal_id: The internal_id of this InlineResponse2003PublicIps.  # noqa: E501
        :type: int
        """

        self._internal_id = internal_id

    @property
    def network_label(self):
        """Gets the network_label of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The network_label of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._network_label

    @network_label.setter
    def network_label(self, network_label):
        """Sets the network_label of this InlineResponse2003PublicIps.


        :param network_label: The network_label of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._network_label = network_label

    @property
    def gateway(self):
        """Gets the gateway of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The gateway of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this InlineResponse2003PublicIps.


        :param gateway: The gateway of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The created_at of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse2003PublicIps.


        :param created_at: The created_at of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this InlineResponse2003PublicIps.  # noqa: E501


        :return: The updated_at of this InlineResponse2003PublicIps.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this InlineResponse2003PublicIps.


        :param updated_at: The updated_at of this InlineResponse2003PublicIps.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2003PublicIps, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2003PublicIps):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2003PublicIps):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Vpsa
from Vpsa.api.servers_api import ServersApi  # noqa: E501
from Vpsa.rest import ApiException


class TestServersApi(unittest.TestCase):
    """ServersApi unit test stubs"""

    def setUp(self):
        self.api = Vpsa.api.servers_api.ServersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_servers_to_volume(self):
        """Test case for attach_servers_to_volume

        """
        pass

    def test_create_server(self):
        """Test case for create_server

        """
        pass

    def test_delete_server(self):
        """Test case for delete_server

        """
        pass

    def test_delete_server_session(self):
        """Test case for delete_server_session

        """
        pass

    def test_get_all_servers(self):
        """Test case for get_all_servers

        """
        pass

    def test_get_server(self):
        """Test case for get_server

        """
        pass

    def test_get_server_performance(self):
        """Test case for get_server_performance

        """
        pass

    def test_get_volumes_attached_to_server(self):
        """Test case for get_volumes_attached_to_server

        """
        pass

    def test_list_server_sessions(self):
        """Test case for list_server_sessions

        """
        pass

    def test_rename_server(self):
        """Test case for rename_server

        """
        pass

    def test_update_server(self):
        """Test case for update_server

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.roles_api import RolesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.roles_api.RolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_role(self):
        """Test case for create_role

        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        """
        pass

    def test_edit_role(self):
        """Test case for edit_role

        """
        pass

    def test_get_role(self):
        """Test case for get_role

        """
        pass

    def test_list_all_permissions(self):
        """Test case for list_all_permissions

        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20022ResponseZcacheUsages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rd_iops': 'int',
        'rd_iotime': 'float',
        'rd_bandwidth': 'float',
        'rd_queue_len': 'int',
        'wrt_iops': 'int',
        'wrt_iotime': 'float',
        'wrt_bandwidth': 'float',
        'wrt_queue_len': 'int',
        'point': 'int'
    }

    attribute_map = {
        'rd_iops': 'rd_iops',
        'rd_iotime': 'rd_iotime',
        'rd_bandwidth': 'rd_bandwidth',
        'rd_queue_len': 'rd_queue_len',
        'wrt_iops': 'wrt_iops',
        'wrt_iotime': 'wrt_iotime',
        'wrt_bandwidth': 'wrt_bandwidth',
        'wrt_queue_len': 'wrt_queue_len',
        'point': 'point'
    }

    def __init__(self, rd_iops=None, rd_iotime=None, rd_bandwidth=None, rd_queue_len=None, wrt_iops=None, wrt_iotime=None, wrt_bandwidth=None, wrt_queue_len=None, point=None, _configuration=None):  # noqa: E501
        """InlineResponse20022ResponseZcacheUsages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._rd_iops = None
        self._rd_iotime = None
        self._rd_bandwidth = None
        self._rd_queue_len = None
        self._wrt_iops = None
        self._wrt_iotime = None
        self._wrt_bandwidth = None
        self._wrt_queue_len = None
        self._point = None
        self.discriminator = None

        if rd_iops is not None:
            self.rd_iops = rd_iops
        if rd_iotime is not None:
            self.rd_iotime = rd_iotime
        if rd_bandwidth is not None:
            self.rd_bandwidth = rd_bandwidth
        if rd_queue_len is not None:
            self.rd_queue_len = rd_queue_len
        if wrt_iops is not None:
            self.wrt_iops = wrt_iops
        if wrt_iotime is not None:
            self.wrt_iotime = wrt_iotime
        if wrt_bandwidth is not None:
            self.wrt_bandwidth = wrt_bandwidth
        if wrt_queue_len is not None:
            self.wrt_queue_len = wrt_queue_len
        if point is not None:
            self.point = point

    @property
    def rd_iops(self):
        """Gets the rd_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The rd_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_iops

    @rd_iops.setter
    def rd_iops(self, rd_iops):
        """Sets the rd_iops of this InlineResponse20022ResponseZcacheUsages.


        :param rd_iops: The rd_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: int
        """

        self._rd_iops = rd_iops

    @property
    def rd_iotime(self):
        """Gets the rd_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The rd_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_iotime

    @rd_iotime.setter
    def rd_iotime(self, rd_iotime):
        """Sets the rd_iotime of this InlineResponse20022ResponseZcacheUsages.


        :param rd_iotime: The rd_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: float
        """

        self._rd_iotime = rd_iotime

    @property
    def rd_bandwidth(self):
        """Gets the rd_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The rd_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: float
        """
        return self._rd_bandwidth

    @rd_bandwidth.setter
    def rd_bandwidth(self, rd_bandwidth):
        """Sets the rd_bandwidth of this InlineResponse20022ResponseZcacheUsages.


        :param rd_bandwidth: The rd_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: float
        """

        self._rd_bandwidth = rd_bandwidth

    @property
    def rd_queue_len(self):
        """Gets the rd_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The rd_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: int
        """
        return self._rd_queue_len

    @rd_queue_len.setter
    def rd_queue_len(self, rd_queue_len):
        """Sets the rd_queue_len of this InlineResponse20022ResponseZcacheUsages.


        :param rd_queue_len: The rd_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: int
        """

        self._rd_queue_len = rd_queue_len

    @property
    def wrt_iops(self):
        """Gets the wrt_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The wrt_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_iops

    @wrt_iops.setter
    def wrt_iops(self, wrt_iops):
        """Sets the wrt_iops of this InlineResponse20022ResponseZcacheUsages.


        :param wrt_iops: The wrt_iops of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: int
        """

        self._wrt_iops = wrt_iops

    @property
    def wrt_iotime(self):
        """Gets the wrt_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The wrt_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_iotime

    @wrt_iotime.setter
    def wrt_iotime(self, wrt_iotime):
        """Sets the wrt_iotime of this InlineResponse20022ResponseZcacheUsages.


        :param wrt_iotime: The wrt_iotime of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: float
        """

        self._wrt_iotime = wrt_iotime

    @property
    def wrt_bandwidth(self):
        """Gets the wrt_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The wrt_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: float
        """
        return self._wrt_bandwidth

    @wrt_bandwidth.setter
    def wrt_bandwidth(self, wrt_bandwidth):
        """Sets the wrt_bandwidth of this InlineResponse20022ResponseZcacheUsages.


        :param wrt_bandwidth: The wrt_bandwidth of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: float
        """

        self._wrt_bandwidth = wrt_bandwidth

    @property
    def wrt_queue_len(self):
        """Gets the wrt_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The wrt_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: int
        """
        return self._wrt_queue_len

    @wrt_queue_len.setter
    def wrt_queue_len(self, wrt_queue_len):
        """Sets the wrt_queue_len of this InlineResponse20022ResponseZcacheUsages.


        :param wrt_queue_len: The wrt_queue_len of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: int
        """

        self._wrt_queue_len = wrt_queue_len

    @property
    def point(self):
        """Gets the point of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501


        :return: The point of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :rtype: int
        """
        return self._point

    @point.setter
    def point(self, point):
        """Sets the point of this InlineResponse20022ResponseZcacheUsages.


        :param point: The point of this InlineResponse20022ResponseZcacheUsages.  # noqa: E501
        :type: int
        """

        self._point = point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20022ResponseZcacheUsages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20022ResponseZcacheUsages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20022ResponseZcacheUsages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20025Cache(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'extra_gb': 'int',
        'extra_partitions': 'int',
        'included_gb': 'int',
        'included_partitions': 'int',
        'total_gb': 'int',
        'total_partitions': 'int'
    }

    attribute_map = {
        'extra_gb': 'extra_gb',
        'extra_partitions': 'extra_partitions',
        'included_gb': 'included_gb',
        'included_partitions': 'included_partitions',
        'total_gb': 'total_gb',
        'total_partitions': 'total_partitions'
    }

    def __init__(self, extra_gb=None, extra_partitions=None, included_gb=None, included_partitions=None, total_gb=None, total_partitions=None, _configuration=None):  # noqa: E501
        """InlineResponse20025Cache - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._extra_gb = None
        self._extra_partitions = None
        self._included_gb = None
        self._included_partitions = None
        self._total_gb = None
        self._total_partitions = None
        self.discriminator = None

        if extra_gb is not None:
            self.extra_gb = extra_gb
        if extra_partitions is not None:
            self.extra_partitions = extra_partitions
        if included_gb is not None:
            self.included_gb = included_gb
        if included_partitions is not None:
            self.included_partitions = included_partitions
        if total_gb is not None:
            self.total_gb = total_gb
        if total_partitions is not None:
            self.total_partitions = total_partitions

    @property
    def extra_gb(self):
        """Gets the extra_gb of this InlineResponse20025Cache.  # noqa: E501


        :return: The extra_gb of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._extra_gb

    @extra_gb.setter
    def extra_gb(self, extra_gb):
        """Sets the extra_gb of this InlineResponse20025Cache.


        :param extra_gb: The extra_gb of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._extra_gb = extra_gb

    @property
    def extra_partitions(self):
        """Gets the extra_partitions of this InlineResponse20025Cache.  # noqa: E501


        :return: The extra_partitions of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._extra_partitions

    @extra_partitions.setter
    def extra_partitions(self, extra_partitions):
        """Sets the extra_partitions of this InlineResponse20025Cache.


        :param extra_partitions: The extra_partitions of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._extra_partitions = extra_partitions

    @property
    def included_gb(self):
        """Gets the included_gb of this InlineResponse20025Cache.  # noqa: E501


        :return: The included_gb of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._included_gb

    @included_gb.setter
    def included_gb(self, included_gb):
        """Sets the included_gb of this InlineResponse20025Cache.


        :param included_gb: The included_gb of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._included_gb = included_gb

    @property
    def included_partitions(self):
        """Gets the included_partitions of this InlineResponse20025Cache.  # noqa: E501


        :return: The included_partitions of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._included_partitions

    @included_partitions.setter
    def included_partitions(self, included_partitions):
        """Sets the included_partitions of this InlineResponse20025Cache.


        :param included_partitions: The included_partitions of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._included_partitions = included_partitions

    @property
    def total_gb(self):
        """Gets the total_gb of this InlineResponse20025Cache.  # noqa: E501


        :return: The total_gb of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._total_gb

    @total_gb.setter
    def total_gb(self, total_gb):
        """Sets the total_gb of this InlineResponse20025Cache.


        :param total_gb: The total_gb of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._total_gb = total_gb

    @property
    def total_partitions(self):
        """Gets the total_partitions of this InlineResponse20025Cache.  # noqa: E501


        :return: The total_partitions of this InlineResponse20025Cache.  # noqa: E501
        :rtype: int
        """
        return self._total_partitions

    @total_partitions.setter
    def total_partitions(self, total_partitions):
        """Sets the total_partitions of this InlineResponse20025Cache.


        :param total_partitions: The total_partitions of this InlineResponse20025Cache.  # noqa: E501
        :type: int
        """

        self._total_partitions = total_partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20025Cache, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20025Cache):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20025Cache):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import Zios
from Zios.models.inline_response20020_response_access_logs import InlineResponse20020ResponseAccessLogs  # noqa: E501
from Zios.rest import ApiException


class TestInlineResponse20020ResponseAccessLogs(unittest.TestCase):
    """InlineResponse20020ResponseAccessLogs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse20020ResponseAccessLogs(self):
        """Test InlineResponse20020ResponseAccessLogs"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Zios.models.inline_response20020_response_access_logs.InlineResponse20020ResponseAccessLogs()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20018ResponseLbg(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'vrid': 'int',
        'ip_v4': 'str',
        'ip_v6': 'str',
        'region_id': 'int',
        'allocation_zone': 'str',
        'allocation_zone_display_name': 'str',
        'vcs': 'str',
        'master_vc': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'vrid': 'vrid',
        'ip_v4': 'ip_v4',
        'ip_v6': 'ip_v6',
        'region_id': 'region_id',
        'allocation_zone': 'allocation-zone',
        'allocation_zone_display_name': 'allocation-zone_display_name',
        'vcs': 'vcs',
        'master_vc': 'master_vc',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, vrid=None, ip_v4=None, ip_v6=None, region_id=None, allocation_zone=None, allocation_zone_display_name=None, vcs=None, master_vc=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20018ResponseLbg - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._vrid = None
        self._ip_v4 = None
        self._ip_v6 = None
        self._region_id = None
        self._allocation_zone = None
        self._allocation_zone_display_name = None
        self._vcs = None
        self._master_vc = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if vrid is not None:
            self.vrid = vrid
        if ip_v4 is not None:
            self.ip_v4 = ip_v4
        if ip_v6 is not None:
            self.ip_v6 = ip_v6
        if region_id is not None:
            self.region_id = region_id
        if allocation_zone is not None:
            self.allocation_zone = allocation_zone
        if allocation_zone_display_name is not None:
            self.allocation_zone_display_name = allocation_zone_display_name
        if vcs is not None:
            self.vcs = vcs
        if master_vc is not None:
            self.master_vc = master_vc
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The name of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20018ResponseLbg.


        :param name: The name of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def vrid(self):
        """Gets the vrid of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The vrid of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: int
        """
        return self._vrid

    @vrid.setter
    def vrid(self, vrid):
        """Sets the vrid of this InlineResponse20018ResponseLbg.


        :param vrid: The vrid of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: int
        """

        self._vrid = vrid

    @property
    def ip_v4(self):
        """Gets the ip_v4 of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The ip_v4 of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._ip_v4

    @ip_v4.setter
    def ip_v4(self, ip_v4):
        """Sets the ip_v4 of this InlineResponse20018ResponseLbg.


        :param ip_v4: The ip_v4 of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._ip_v4 = ip_v4

    @property
    def ip_v6(self):
        """Gets the ip_v6 of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The ip_v6 of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._ip_v6

    @ip_v6.setter
    def ip_v6(self, ip_v6):
        """Sets the ip_v6 of this InlineResponse20018ResponseLbg.


        :param ip_v6: The ip_v6 of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._ip_v6 = ip_v6

    @property
    def region_id(self):
        """Gets the region_id of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The region_id of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: int
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this InlineResponse20018ResponseLbg.


        :param region_id: The region_id of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: int
        """

        self._region_id = region_id

    @property
    def allocation_zone(self):
        """Gets the allocation_zone of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The allocation_zone of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone

    @allocation_zone.setter
    def allocation_zone(self, allocation_zone):
        """Sets the allocation_zone of this InlineResponse20018ResponseLbg.


        :param allocation_zone: The allocation_zone of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._allocation_zone = allocation_zone

    @property
    def allocation_zone_display_name(self):
        """Gets the allocation_zone_display_name of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The allocation_zone_display_name of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_display_name

    @allocation_zone_display_name.setter
    def allocation_zone_display_name(self, allocation_zone_display_name):
        """Sets the allocation_zone_display_name of this InlineResponse20018ResponseLbg.


        :param allocation_zone_display_name: The allocation_zone_display_name of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._allocation_zone_display_name = allocation_zone_display_name

    @property
    def vcs(self):
        """Gets the vcs of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The vcs of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._vcs

    @vcs.setter
    def vcs(self, vcs):
        """Sets the vcs of this InlineResponse20018ResponseLbg.


        :param vcs: The vcs of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._vcs = vcs

    @property
    def master_vc(self):
        """Gets the master_vc of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The master_vc of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._master_vc

    @master_vc.setter
    def master_vc(self, master_vc):
        """Sets the master_vc of this InlineResponse20018ResponseLbg.


        :param master_vc: The master_vc of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._master_vc = master_vc

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The created_at of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20018ResponseLbg.


        :param created_at: The created_at of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20018ResponseLbg.  # noqa: E501


        :return: The modified_at of this InlineResponse20018ResponseLbg.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20018ResponseLbg.


        :param modified_at: The modified_at of this InlineResponse20018ResponseLbg.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20018ResponseLbg, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20018ResponseLbg):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20018ResponseLbg):
            return True

        return self.to_dict() != other.to_dict()
